<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Hüvelyk</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Láb</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Mérföld</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Milliméter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centiméter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Méter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilométer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Mikrohüvelyk</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Thou</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angström</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanométer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Deciméter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekaméter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hektométer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigaméter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Csillagászati egység</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Fényév</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parszek</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>Réteg szerint</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Blokk szerint</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Piros</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Zöld</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Kék</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Cián</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Sárga</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Narancssárga</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Sötétvörös</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Sötétzöld</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Sötétkék</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Sötétcián</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Sötétmagenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Sötétsárga</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Fekete</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Szürke</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Világosszürke</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Fehér</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Továbbiak...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>Jelenlegi réteg azonosítója</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Rajzolási mértékegység</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Vonaltípus léptéke</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Méretvonalak betűtípusa</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/REntity.cpp" line="+95"/>
        <source>Block</source>
        <translation>Blokk</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+75"/>
        <source>Pixel Unit</source>
        <translatorcomment>The units of the entity are measured in pixels rather than drawing units, i.e. 10 means 10 pixels on the screen.</translatorcomment>
        <translation>Pixel egység</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+83"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origó</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Elrendezés</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Referencia birtokában</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Külső hivatkozás</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
        <source>Referenced Block</source>
        <translation>Hivatkozott blokk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>Külső hivatkozás</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translatorcomment>Blokk beszúrásakor használja, az eredetinél kisebb vagy nagyobb mérethez</translatorcomment>
        <translation>Lépték</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Szög</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translatorcomment>Blokkok többszörös beszúrásakor</translatorcomment>
        <translation>Oszlopok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translatorcomment>Blokkok többszörös beszúrásakor</translatorcomment>
        <translation>Sorok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translatorcomment>Blokkok többszörös beszúrásakor</translatorcomment>
        <translation>Oszlopköz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translatorcomment>Blokkok többszörös beszúrásakor</translatorcomment>
        <translation>Sorköz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attribútumok</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="-1"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layer</source>
        <translation>Réteg</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+104"/>
        <source>Linetype</source>
        <translation>Vonaltípus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Vonaltípus léptéke</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Vonalvastagság</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Megjelenített szín</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Rajzolási sorrend</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Szülő azonosító</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Befoglaló</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Alul</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Felül</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Egyéni</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Azonosító</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Védett</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Kijelölt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Láthatatlan tárgy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Munkakészlet</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Egyszerű</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Szövegpozíció</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Egyszerű szöveg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Betűtípus neve</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Szöveg magassága</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Szöveg szélessége</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Szöveg szöge</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X lépték</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Félkövér</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Dőlt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Sortávolság</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Igazítás</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Vízszintes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Függőleges</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>Visszafelé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>Fejjel lefelé</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Forgatás</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Bekapcsolva</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Nézet középpontja</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translatorcomment>The point at the center of a viewport, the point we are looking at.</translatorcomment>
        <translation>Nézet célja</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translatorcomment>The main viewport used to display the whole drawing.</translatorcomment>
        <translation>Teljes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Fagyasztott rétegek</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>Réteg azonosító</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-8"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Rejtett</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Fagyasztott</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Zárolt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Összecsukott</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Nyomtatható</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Illesztést fogad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translatorcomment>Switching a layer off means that it will also be frozen.</translatorcomment>
        <translation>Ki = Fagyasztott</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Tab sorrend</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min. határok</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max. határok</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Beszúrási alap</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min. kiterjedés</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max. kiterjedés</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Körkörös (rekurzív) blokkreferencia észlelve:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Blokk neve:</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Stílus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overall scale</source>
        <translation>Általános lépték</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear measurement factor</source>
        <translation>Lineáris mérési tényező</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Szöveg magassága</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Méretvonal hézag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translatorcomment>Nyíl vagy </translatorcomment>
        <translation>Nyíl mérete</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Méretvonal növekmény</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Méretsegédvonal hosszabbítása</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Méretsegédvonal eltolása</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Szöveg pozíciója függőlegesen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text horizontal</source>
        <translatorcomment>A preference to show the dimension label always horizontally rather than aligned with the dimension line.</translatorcomment>
        <translation>Szöveg vízszintesen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translatorcomment>A méretvonal végén nyíl helyett használható ferde vonalszakasz mérete</translatorcomment>
        <translation>Jelölés mérete</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translatorcomment>Azt adja meg, hogy a méretvonalra írt számot pl 1.5 vagy 1 1/2 stb formátumban írja rá</translatorcomment>
        <translation>Lineáris formátum</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Tizedesjegyek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Tizedeselválasztó</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Nullák elhagyása</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Szög formátum</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Szög tizedesjegyek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Szög nullák elhagyása</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Határolók ferde vonalkával</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Szöveg színe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translatorcomment>A block containing the arrow of a dimension.</translatorcomment>
        <translation>Nyíl blokk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Nyíl blokk 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Nyíl blokk 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Kijelölést igényel</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrikus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Mintázat</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>Réteg szerint</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Blokk szerint</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Folytonos</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Határ</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Középvonal</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Pontvonal</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Szaggatott</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Kétpontvonal</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Pontozott</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Rejtett</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Fantom</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO szaggatott</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO szaggatott ritka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO hosszú pontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO kétpontos hosszú pontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO hárompontos-hosszú pontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO pontozott</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO hosszú-rövid szaggatott</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO hosszú és két rövid szaggatott</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO pontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO kétvonalas pontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO kétpontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO kétvonalas kétpontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO hárompontos pontvonal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO hárompontos két vonalas pontvonal</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Meleg víz betáp</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Meleg víz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gázvezeték</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Kacskaringós</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Cikkcakk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Pálya</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Kerítés 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Kerítés 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Pont 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Pont 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Üzem</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Víz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Vízelvezetés</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Vízelvezetés megfordítva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Kommunikáció</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Elektromos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Alacsony feszültség</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Nagyfeszültség</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Elektromos légvezeték</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translatorcomment>A line type used for foul (dirty) water.</translatorcomment>
        <translation>Szennyezett víz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translatorcomment>A line type used for foul (dirty) water that is rising.</translatorcomment>
        <translation>Emelkedő szennyezett víz</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>Réteg szerint</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Blokk szerint</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11 mm</translation>
    </message>
</context>
</TS>
